

clear all
set more off
version 16
set seed 16

// Define global macros for graph dimensions
global Width16x9 = 1920*2
global Height16x9 = 1080*2
global Width4x3 = 1440*2
global Height4x3 = 1080*2

// The global macros "$GoogleDriveLaptop" and "$GoogleDriveWork"
// are defined my profile here:  c:\ado\profile.do
capture cd "$GoogleDriveWork"
capture cd "$GoogleDriveLaptop"
capture cd "$Presentations"
capture cd ".\Talks\AllTalks\05_Regression\examples"

capture log close
log using regression, replace


// OPEN THE DATASET "nhanes120.dta"
use nhanes_clean.dta

// DESCRIBE AND SUMMARIZE THE DATA
//describe id-diabetes dob bmi HighBP
describe
summarize

// CREATE A HISTOGRAM OF SYSTOLIC BLOOD PRESSURE (sbp)
histogram sbp
histogram sbp, normal normopts(lcolor(blue) lwidth(thick)) kdensity kdenopts(lcolor(green) lwidth(thick))
graph export ./graphs/histogram.png, as(png) width($Width4x3) height($Height4x3) replace


// CREATE A BOXPLOT OF sbp BY sex
graph box sbp, over(sex)
graph export ./graphs/boxplot_sex.png, as(png) width($Width4x3) height($Height4x3) replace

// LINEAR REGRESSION WITH BINARY COVARIATE sex
regress sbp sex
list sex i.sex in 1/10
regress sbp i.sex
margins sex
marginsplot 
graph export ./graphs/marginsplot_sex1.png, as(png) width($Width4x3) height($Height4x3) replace

marginsplot, recast(bar)
graph export ./graphs/marginsplot_sex2.png, as(png) width($Width4x3) height($Height4x3) replace


// CREATE A BOXPLOT OF sbp BY race
graph box sbp, over(race)
graph export ./graphs/boxplot_race.png, as(png) width($Width4x3) height($Height4x3) replace

// LINEAR REGRESSION WITH CATEGORICAL COVARIATE race
list race i.race in 170/179
regress sbp i.race
margins race
marginsplot 
graph export ./graphs/marginsplot_race1.png, as(png) width($Width4x3) height($Height4x3) replace

// RECAST THE MARGINSPLOT AS A BAR CHART
marginsplot, recast(bar)
graph export ./graphs/marginsplot_race2.png, as(png)      ///
             width($Width4x3) height($Height4x3) replace

// MARGINAL CONTRASTS
margins g.race, mcompare(scheffe) contrast(nowald)
marginsplot, yline(0) plotregion(margin(l=15 r=15)) 
graph export ./graphs/marginsplot_race3.png, as(png)      ///
             width($Width4x3) height($Height4x3) replace
             
// MARGINS PAIRWISE COMPARISONS
margins race, pwcompare mcompare(bonferroni)
marginsplot, xdimension(_pw) unique yline(0) plotregion(margin(l=10 r=10))
graph export ./graphs/marginsplot_race4.png, as(png)      ///
             width($Width4x3) height($Height4x3) replace










// CREATE A SCATTERPLOT OF sbp AND age
twoway (scatter sbp age) (lowess sbp age, lcolor(red) lwidth(thick))
graph export ./graphs/scatterplot.png, as(png) width($Width4x3) height($Height4x3) replace

// LINEAR REGRESSION WITH BINARY COVARIATE race
regress sbp age
margins, at(age=(20(10)70)) vsquish
marginsplot 
graph export ./graphs/marginsplot_age1.png, as(png) width($Width4x3) height($Height4x3) replace

marginsplot, recast(line) recastci(rarea) ciopts(fcolor(ltblue))
graph export ./graphs/marginsplot_age2.png, as(png) width($Width4x3) height($Height4x3) replace


// MULTIPLE REGRESSION
regress sbp i.sex i.race age

margins sex, at(age=(20(10)60)) vsquish
marginsplot
graph export ./graphs/marginsplot_sex_age.png, as(png)   ///
             width($Width4x3) height($Height4x3) replace

margins race, at(age=(20(10)60)) vsquish
marginsplot, legend(rows(1))
graph export ./graphs/marginsplot_race_age.png, as(png) width($Width4x3) height($Height4x3) replace



// FACTOR VARIABLE OPERATORS
list i.sex i.race i.sex#i.race in 1/5

list i.sex##i.race in 1/5

sort cholesterol
list c.age i.sex c.age#i.sex in 1/5

list c.age##i.sex in 1/5


// INTERACTION: BINARY MODERATOR: sex
// ==================================
regress sbp c.age i.sex c.age#i.sex
regress sbp c.age##i.sex
margins sex, at(age=(20(10)60)) vsquish
marginsplot
graph export ./graphs/marginsplot_sex.png, as(png) ///
              width($Width4x3) height($Height4x3) replace

// F-test for interaction
regress sbp c.age##i.sex
testparm c.age#i.sex

// Likelihood ratio ttest for interaction
quietly regress sbp c.age i.sex
estimates store no_int
quietly regress sbp c.age i.sex c.age#i.sex
estimates store w_int
lrtest w_int no_int



// INTERACTION: CATEGORICAL MODERATOR: race
// ========================================
regress sbp c.age##i.race
margins race, at(age=(20(10)60)) vsquish
marginsplot, legend(rows(1))
graph export ./graphs/marginsplot_race.png, as(png) ///
              width($Width4x3) height($Height4x3) replace

// F-test for interaction
regress sbp c.age##i.race
testparm c.age#i.race

// Likelihood ratio ttest for interaction
quietly regress sbp c.age i.race c.age#i.race
estimates store w_int
quietly regress sbp c.age i.race
estimates store no_int
lrtest w_int no_int



// Contour plots for continuous-by-continuous interactions
use nhanes_clean.dta, clear
regress sbp c.age##c.weight
quietly margins, at(age=(20(5)60) weight=(40(5)160))      ///
                 saving(predictions.dta, replace)vsquish
use predictions.dta, clear
describe _margin _at1 _at2
rename _margin pr_sbp
rename _at1 age
rename _at2 weight
describe pr_sbp age weight

twoway  (contour pr_sbp weight age, ccuts(100(7)170)),  ///                
         xlabel(20(10)60)                               ///
         ylabel(40(20)160, angle(horizontal))           ///
         xtitle("Age (years)")                          ///
         ytitle("Weight (kg)")                          ///
         ztitle("Expected SBP")                         ///
         title("Expected SBP by Age and Weight")
graph export ./graphs/marginsplot_age_weight.png, as(png) ///
              width($Width4x3) height($Height4x3) replace

              
              
              
// LOG TRANSFORMATIONS
// =========================================================
use nhanes_clean.dta, clear
histogram triglycerides, title("Serum Triglycerides (mg/dL)")
graph export ./graphs/histogram_trig1.png, as(png)       ///
             width($Width4x3) height($Height4x3) replace
 
generate ln_trig = ln(triglycerides) 
histogram ln_trig, title("ln(Triglycerides)")
graph export ./graphs/histogram_trig2.png, as(png)       ///
             width($Width4x3) height($Height4x3) replace
   
regress ln_trig c.age
margins, at(age=(20(10)60)) vsquish
marginsplot
graph export ./graphs/marginsplot_lntrig1.png, as(png)       ///
             width($Width4x3) height($Height4x3) replace

margins, expression(exp(predict(xb))) at(age=(20(10)60))
marginsplot
graph export ./graphs/marginsplot_lntrig2.png, as(png)       ///
             width($Width4x3) height($Height4x3) replace

poisson triglycerides c.age, vce(robust)
margins, at(age=(20(10)60))
marginsplot, ytitle("Predicted Triglycerides")
graph export ./graphs/marginsplot_lntrig3.png, as(png)       ///
             width($Width4x3) height($Height4x3) replace              
              
   
              
              
              
              
              
              
              

// REGRESSION DIAGNOSTICS
use nhanes_clean.dta, clear
regress sbp c.age##i.sex
predict residuals, residuals

// CHECK THE NORMALITY OF THE RESIDUALS
histogram residuals, normal normopts(lcolor(blue) lwidth(thick)) kdensity kdenopts(lcolor(green) lwidth(thick))
graph export ./graphs/residuals_histogram.png, as(png) width($Width4x3) height($Height4x3) replace


// TEST THE NORMALITY OF THE RESIDUALS
swilk residuals
sfrancia residuals
sktest residuals

// CHECK FOR HETEROSKEDASTICITY WITH A RESIDUAL-VS-FITTED PLOT
rvfplot, yline(0)
graph export ./graphs/residuals_rvfplot.png, as(png) width($Width4x3) height($Height4x3) replace

// CHECK FOR HETEROSKEDASTICITY
estat hettest, rhs mtest(bonf)
estat szroeter, rhs mtest(bonf)

// MULTIPLE REGRESSION WITH ROBUST STANDARD ERRORS
regress sbp i.sex i.race age, robust

// MULTIPLE REGRESSION WITH BOOSTRAP STANDARD ERRORS
regress sbp i.sex i.race age, vce(bootstrap, reps(100) seed(12345))

log close

translate "regression.smcl" "regression.log", replace linesize(120) translator(smcl2log)





